# PirxcyPinger
Use This To Upload Files To PirxcyPinger

[![Downloads](https://pepy.tech/badge/PirxcyPinger)](https://pepy.tech/project/PirxcyPinger)
[![Downloads](https://pepy.tech/badge/pirxcypinger/week)](https://pepy.tech/project/pirxcypinger)
[![Downloads](https://pepy.tech/badge/pirxcypinger/month)](https://pepy.tech/project/pirxcypinger)
[![Requires: Python 3.x](https://img.shields.io/pypi/pyversions/PirxcyPinger.svg)](https://pypi.org/project/PirxcyPinger/)
[![Version: 1.0.0](https://img.shields.io/pypi/v/PirxcyPinger.svg)](https://pypi.org/project/PirxcyPinger/)

### Setup:
``pip3 install PirxcyPinger``

[Examples](https://github.com/PirxcyFinal/PirxcyPinger/tree/main/Examples "github.com/PirxcyFinal/PirxcyPinger/tree/main/Examples")

